@@ -1,27 +1,10 @@
-from typing import Set, List
-import subprocess
-from abc import abstractmethod
-from dataclasses import dataclass
+from typing import FrozenSet, List, Set
 
 import urwid
 
-from ovshell import api
-from ovshell import widget
+from ovshell import api, widget
 
-
-@dataclass
-class UpgradablePackage:
-    name: str
-    old_version: str
-    new_version: str
-
-
-class OpkgTools:
-    opkg_binary: str
-
-    @abstractmethod
-    def list_upgradables(self) -> List[UpgradablePackage]:
-        """Return list of upgradable packages"""
+from .opkg import OpkgTools, UpgradablePackage, create_opkg_tools
 
 
 class UnselectableTerminal(urwid.Terminal):
@@ -32,30 +15,6 @@ class UnselectableTerminal(urwid.Terminal):
         return key
 
 
-class OpkgToolsImpl(OpkgTools):
-    def __init__(self, opkg_binary: str):
-        self.opkg_binary = opkg_binary
-
-    def list_upgradables(self) -> List[UpgradablePackage]:
-        proc = subprocess.run(
-            [self.opkg_binary, "list-upgradable"], capture_output=True
-        )
-        if proc.returncode != 0:
-            return []
-
-        blines = proc.stdout.split(b"\n")
-        upgradables = []
-        for bline in blines:
-            line = bline.decode().strip()
-            items = line.split(" - ")
-            if len(items) != 3:
-                # Bad format
-                continue
-            pkgname, old_version, new_version = items
-            upgradables.append(UpgradablePackage(pkgname, old_version, new_version))
-        return upgradables
-
-
 class SystemUpgradeApp(api.App):
     name = "system-upgrade"
     title = "Update"
@@ -66,8 +25,7 @@ class SystemUpgradeApp(api.App):
         self.shell = shell
 
     def launch(self) -> None:
-        opkg_bin = self.shell.os.path("//usr/bin/opkg")
-        opkg_tools = OpkgToolsImpl(opkg_bin)
+        opkg_tools = create_opkg_tools(self.shell.os)
         act = CheckForUpdatesActivity(self.shell, opkg_tools)
         self.shell.screen.push_activity(act)
 
@@ -81,7 +39,7 @@ class CheckForUpdatesActivity(api.Activity):
         self.opkg_tools = opkg_tools
 
     def create(self) -> urwid.Widget:
-        ui = CheckForUpdatesWidget(self.opkg_tools)
+        ui = CheckForUpdatesWidget(self.opkg_tools, self.shell.screen, self)
         urwid.connect_signal(ui, "continue", self._on_continue)
         urwid.connect_signal(ui, "exit", self._on_exit)
         self.check_for_updates_wdg = ui
@@ -115,9 +73,13 @@ class CheckForUpdatesWidget(urwid.WidgetWrap):
 
     upgradables: List[UpgradablePackage]
 
-    def __init__(self, opkg_tools: OpkgTools) -> None:
+    def __init__(
+        self, opkg_tools: OpkgTools, screen: api.ScreenManager, activity: api.Activity
+    ) -> None:
         self.opkg_tools = opkg_tools
         check_for_updates_wdg = self._create_opkg_update_screen()
+        self._screen = screen
+        self._activity = activity
         super().__init__(check_for_updates_wdg)
 
     def _create_opkg_update_screen(self) -> urwid.Widget:
@@ -130,7 +92,7 @@ class CheckForUpdatesWidget(urwid.WidgetWrap):
         )
 
         content = urwid.Pile(
-            [("pack", self.message_line), ("pack", urwid.Divider()), update_term,]
+            [("pack", self.message_line), ("pack", urwid.Divider()), update_term]
         )
         # Force pack to be selectable, even though no widget is selectable at
         # the moment.
@@ -138,13 +100,17 @@ class CheckForUpdatesWidget(urwid.WidgetWrap):
         return content
 
     def _create_update_terminal(self) -> urwid.Widget:
-        cmd = [self.opkg_tools.opkg_binary, "update"]
+        cmd = [self.opkg_tools.get_opkg_binary(), "update"]
         self.term = UnselectableTerminal(cmd)
         urwid.connect_signal(self.term, "closed", self._on_opkg_update_finished)
         return urwid.AttrMap(self.term, "bg")
 
     def _on_opkg_update_finished(self, wdg: urwid.Widget) -> None:
-        self.upgradables = self.opkg_tools.list_upgradables()
+        self._screen.spawn_task(self._activity, self._list_upgradables())
+
+    async def _list_upgradables(self) -> None:
+        self.upgradables = await self.opkg_tools.list_upgradables()
+
         if self.upgradables:
             continue_btn = widget.PlainButton(" Continue ")
             urwid.connect_signal(continue_btn, "click", self._on_continue)
@@ -158,7 +124,7 @@ class CheckForUpdatesWidget(urwid.WidgetWrap):
         else:
             exit_btn = widget.PlainButton(" Exit ")
             urwid.connect_signal(exit_btn, "click", self._on_exit)
-            message = [("remark", f"No updates found")]
+            message = [("remark", "No updates found")]
             message_wdg = urwid.Columns(
                 [("pack", urwid.Text(message)), ("pack", exit_btn)], dividechars=1,
             )
@@ -187,6 +153,9 @@ class PackageSelectionWidget(urwid.WidgetWrap):
         content = self._create_package_list_screen()
         super().__init__(content)
 
+    def sizing(self) -> FrozenSet[str]:
+        return frozenset(["box"])
+
     def _create_package_list_screen(self) -> urwid.Widget:
         self._package_walker = urwid.SimpleFocusListWalker([])
         self._update_packages()
@@ -288,7 +257,7 @@ class SystemUpgradeWidget(urwid.WidgetWrap):
         )
 
         content = urwid.Pile(
-            [("pack", self.message_line), ("pack", urwid.Divider()), update_term,]
+            [("pack", self.message_line), ("pack", urwid.Divider()), update_term]
         )
         # Force pack to be selectable, even though no widget is selectable at
         # the moment.
@@ -296,7 +265,7 @@ class SystemUpgradeWidget(urwid.WidgetWrap):
         return content
 
     def _create_upgrade_terminal(self) -> urwid.Widget:
-        cmd = [self.opkg_tools.opkg_binary, "upgrade"] + self._packages
+        cmd = [self.opkg_tools.get_opkg_binary(), "upgrade"] + self._packages
         self.term = UnselectableTerminal(cmd)
         urwid.connect_signal(self.term, "closed", self._on_opkg_upgrade_finished)
         return urwid.AttrMap(self.term, "bg")
@@ -304,7 +273,7 @@ class SystemUpgradeWidget(urwid.WidgetWrap):
     def _on_opkg_upgrade_finished(self, wdg: urwid.Widget) -> None:
         exit_btn = widget.PlainButton(" Exit ")
         urwid.connect_signal(exit_btn, "click", self._on_exit)
-        message = ("success message", f"Upgrade completed!")
+        message = ("success message", "Upgrade completed!")
         message_wdg = urwid.Columns(
             [("pack", urwid.Text(message)), ("pack", exit_btn)], dividechars=1,
         )
